@@ -1,6 +1,7 @@
 from __future__ import annotations
 from datetime import datetime
-
+from dataclasses import dataclass, field
+from typing import Optional
 
 class FeedbackScore:
     category: str
@@ -9,14 +10,15 @@ class FeedbackScore:
     phq_9: str
 
 
+@dataclass
 class Prediction:
     session_id: str
-    predicted_score: dict = {}
-    feedback_score: FeedbackScore
     created_at: datetime
     updated_at: datetime
     is_calibrated: bool
     status: str
+    feedback_score: Optional[FeedbackScore] = None
+    predicted_score: dict = field(default_factory=dict)
 
     def get_score(self, category: str) -> str | None:
         return self.predicted_score.get(category, None)
